from PyQt6.QtWidgets import QWidget, QVBoxLayout, QPushButton, QLabel, QTableWidget, QTextEdit, QHBoxLayout

def create_upload_tab(parent):
    tab = QWidget()
    layout = QVBoxLayout()
    parent.upload_button = QPushButton("Upload CSV File")
    parent.upload_button.clicked.connect(parent.load_csv_file)
    parent.file_label = QLabel("No file selected")
    layout.addWidget(parent.upload_button)
    layout.addWidget(parent.file_label)
    tab.setLayout(layout)
    return tab

def create_dashboard_tab(parent):
    tab = QWidget()
    layout = QVBoxLayout()
    parent.table_widget = QTableWidget()
    layout.addWidget(parent.table_widget)
    
    button_layout = QHBoxLayout()
    parent.referral_button = QPushButton("Need Referral")
    parent.referral_button.clicked.connect(parent.filter_referrals)
    parent.reset_button = QPushButton("Show All")
    parent.reset_button.clicked.connect(parent.reset_table)
    
    button_layout.addWidget(parent.referral_button)
    button_layout.addWidget(parent.reset_button)
    layout.addLayout(button_layout)
    
    tab.setLayout(layout)
    return tab

def create_analytics_tab(parent):
    tab = QWidget()
    layout = QVBoxLayout()
    parent.patient_count_label = QLabel("Total Patients: 0")
    layout.addWidget(parent.patient_count_label)
    tab.setLayout(layout)
    return tab

def create_help_tab():
    tab = QWidget()
    layout = QVBoxLayout()
    help_text = QTextEdit()
    help_text.setReadOnly(True)
    help_text.setStyleSheet("background-color: #EAEAEA; color: #222222; padding: 10px; border-radius: 8px;")
    help_text.setHtml("""
    <html>
    <head>
        <style>
            h1 { font-size: 22px; font-weight: bold; color: #333366; }
            h2 { font-size: 18px; font-weight: bold; color: #444488; margin-top: 15px; }
            p { font-size: 14px; color: #222222; margin-left: 10px; }
            ul { font-size: 14px; color: #222222; margin-left: 20px; }
        </style>
    </head>
    <body>
        <h1>How to Use the Feeding Dashboard</h1>
        
        <p>This program is designed and developed for the CCU staff in order to help monitor patients and identify which patients need referral to a dietitian. 
        Below are the instructions for each tab:</p>
        
        <h2>1. Upload CSV File Tab</h2>
        <ul>
            <li>Click the <b>"Upload CSV File"</b> button.</li>
            <li>Select a CSV file containing patient data.</li>
            <li>The file will be loaded (it can take a while depending on the file size) and now you can see a list with all the patients and their data on the View Dashboard Tab</li>
        </ul>
        
        <h2>2. View Dashboard Tab</h2>
        <ul>
            <li>Displays a table of all admitted patients.</li>
            <li>Click <b>"Need Referral"</b> to filter and show only patients requiring referral.</li>
            <li>Click <b>"Show All"</b> to reset the table and display all patients.</li>
        </ul>
        
        <h2>3. Analytics Tab</h2>
        <ul>
            <li>Shows a <b>total count of current patients</b>.</li>
            <li>Displays a <b>pie chart</b> with the percentage and exact number of patients who need and don’t need referral.</li>
            <li>Displays a <b>bar chart</b> for missing patient data, showing the exact number of missing entries for each category.</li>
        </ul>
        
        <h2>4. Help Tab</h2>
        <ul>
            <li>Provides an overview of how to use the application.</li>
        
        </ul>
        
        <h2>Additional Notes</h2>
        <ul>
            <li>Make sure that the CSV files are not corrupted and include ideally all the data for the best results. </li>
            <li>The graphs and charts on the analytics tab, refresh automatically with every new csv upload.</li>
        </ul>
    </body>
    </html>
    """)
    layout.addWidget(help_text)
    tab.setLayout(layout)
    return tab